@@ -53,14 +53,14 @@ func.trimvar.RT=function(fdataobj,...){
  func.var(fdataobj[lista,])}
 
 #  for multivarate data
-func.trim.SD=function(fdataobj,...){depth.SD(fdataobj,...)$mtrim}
-func.trim.PD=function(fdataobj,...){depth.PD(fdataobj,...)$mtrim}
-func.trim.HD=function(fdataobj,...){depth.HD(fdataobj,...)$mtrim} 
-func.trim.MhD=function(fdataobj,...){depth.MhD(fdataobj,...)$mtrim}
+# func.trim.SD=function(fdataobj,...){depth.SD(fdataobj,...)$mtrim}
+# func.trim.PD=function(fdataobj,...){depth.PD(fdataobj,...)$mtrim}
+# func.trim.HD=function(fdataobj,...){depth.HD(fdataobj,...)$mtrim} 
+# func.trim.MhD=function(fdataobj,...){depth.MhD(fdataobj,...)$mtrim}
 
-func.med.SD=function(fdataobj,...){depth.SD(fdataobj,...)$median} 
-func.med.PD=function(fdataobj,...){depth.PD(fdataobj,...)$median}
-func.med.HD=function(fdataobj,...){ depth.HD(fdataobj,...)$median}
-func.med.MhD=function(fdataobj,...){ depth.MhD(fdataobj,...)$median}
+# func.med.SD=function(fdataobj,...){depth.SD(fdataobj,...)$median} 
+# func.med.PD=function(fdataobj,...){depth.PD(fdataobj,...)$median}
+# func.med.HD=function(fdataobj,...){ depth.HD(fdataobj,...)$median}
+# func.med.MhD=function(fdataobj,...){ depth.MhD(fdataobj,...)$median}
 
 
