@@ -188,7 +188,7 @@ sd.X <- sqrt(apply(X, 2, var))
  #   TT = X %*% V  ## son los scores
     l<-1:ncomp
     colnames(scores) <- paste("PLS", l, sep = "")
-    outlist = list(call=C,df = DoF, rotation=V2,x=scores,lambda=lambda,P=P,
+    outlist = list(call=C,df = DoF, rotation=V2,x=scores,lambda=lambda,P=P,norm=norm,
     fdataobj=fdataobj,y=y0,l=l,fdataobj.cen=center$Xcen,mean=mean.X,Yhat = Yhat,yhat = yhat)
 #    Yhat = Yhat, coyhat = yhat,efficients = coefficients,intercept = intercept,
 #     RSS = RSS,TT=TT, sigmahat = sigmahat,covariance = covariance,
@@ -197,6 +197,7 @@ sd.X <- sqrt(apply(X, 2, var))
     return(outlist)
 }
 
+
 ###############
 ################################################################
 ################################################################
@@ -503,7 +504,7 @@ else {
     GCV <- sum(e^2)/rdf^2
  out <- list(call = C, beta.est = beta.est,coefficients=object.lm$coefficients,
  fitted.values =object.lm$fitted.values, residuals = object.lm$residuals,
- H=H,df = df,r2=r2, GCV=GCV,sr2 = sr2, l = l,lambda=lambda,P=P, fdata.comp=pc,
+ H=H,df = df,r2=r2, GCV=GCV,sr2 = sr2, l = l,lambda=lambda,P=P, fdata.comp=pc,rn=0,
  lm=object.lm,fdataobj = fdataobj,y = y)
  #pc=pc,pf = pf,Z=Z
  class(out) = "fregre.fd"
@@ -563,22 +564,30 @@ else {
     H<-Z%*%S%*%t(Z)
     e<-object.lm$residuals
 #    df = traza(H)
-   df<-pc$df[lenl]+1
+    df<-pc$df[lenl]+1
     rdf<-n-df
     sr2 <- sum(e^2)/rdf
     r2 <- 1 - sum(e^2)/sum(ycen^2)
     r2.adj<- 1 - (1 - r2) * ((n -    1)/ rdf)
     GCV <- sum(e^2)/rdf^2
- out <- list(call = C, beta.est = beta.est,coefficients=object.lm$coefficients,
+  
+        colnames(Z)[1] = "(Intercept)"
+        std.error = sqrt(diag(S) *sr2)
+        t.value =object.lm$coefficients/std.error
+        p.value = 2 * pt(abs(t.value), n - df, lower.tail = FALSE)
+        coefficients <- cbind(object.lm$coefficients, std.error, t.value, p.value)
+        colnames(coefficients) <- c("Estimate", "Std. Error",
+            "t value", "Pr(>|t|)")
+ out <- list(call = C, beta.est = beta.est,coefficients=object.lm$coefficients, coefs=coefficients,
  fitted.values =object.lm$fitted.values, residuals = object.lm$residuals,
- H=H,df = df,r2=r2, GCV=GCV,sr2 = sr2, l = l,lambda=lambda,P=P, fdata.comp=pc,
+ H=H,df = df,r2=r2, GCV=GCV,sr2 = sr2, l = l,lambda=lambda,P=P, fdata.comp=pc,rn=0,
  lm=object.lm,fdataobj = fdataobj,y = y)
     class(out) = "fregre.fd"
     return(out)
 }
 #################################################################
 #################################################################
-
+    
 
 #################################################################
 #################################################################
